@@ -22,36 +22,37 @@ bartMachine = function(X = NULL, y = NULL, Xy = NULL,
     impute_missingness_with_rf_impute = FALSE,
     impute_missingness_with_x_j_bar_for_lm = TRUE,
     mem_cache_for_speed = TRUE,
+	serialize = FALSE,
     verbose = TRUE){
  
     bart_machine = build_bart_machine(X, y, Xy, 
-    num_trees, #
-    num_burn_in, 
-    num_iterations_after_burn_in, 
-    alpha,
-    beta,
-    k,
-    q,
-    nu,
-    prob_rule_class,
-    mh_prob_steps,
-    debug_log,
-    run_in_sample,
-    s_sq_y,
-    #print_tree_illustrations = FALSE
-    cov_prior_vec = NULL,
-    use_missing_data,
-    covariates_to_permute, 
-    num_rand_samps_in_library , 
-    use_missing_data_dummies_as_covars,
-    replace_missing_data_with_x_j_bar,
-    impute_missingness_with_rf_impute,
-    impute_missingness_with_x_j_bar_for_lm,
-    mem_cache_for_speed,
-    verbose )
+	    num_trees, #
+	    num_burn_in, 
+	    num_iterations_after_burn_in, 
+	    alpha,
+	    beta,
+	    k,
+	    q,
+	    nu,
+	    prob_rule_class,
+	    mh_prob_steps,
+	    debug_log,
+	    run_in_sample,
+	    s_sq_y,
+	    #print_tree_illustrations = FALSE
+	    cov_prior_vec = NULL,
+	    use_missing_data,
+	    covariates_to_permute, 
+	    num_rand_samps_in_library , 
+	    use_missing_data_dummies_as_covars,
+	    replace_missing_data_with_x_j_bar,
+	    impute_missingness_with_rf_impute,
+	    impute_missingness_with_x_j_bar_for_lm,
+	    mem_cache_for_speed,
+		serialize,
+	    verbose)
 
     bart_machine
-  
 }
 
 
@@ -67,3 +68,13 @@ bartMachineCV = function(X = NULL, y = NULL, Xy = NULL,
    nu_q_cvs ,
    k_folds, ...)
 }
+
+unserialize_bart_machine_if_necessary = function(bart_machine){
+	if (is.jnull(bart_machine$java_bart_machine)){
+		stop("The bartMachine object")
+	}
+	
+	if (is.jnull(bart_machine$java_bart_machine)){
+		stop("The bartMachine object")
+	}
+}
